function input(){
	f=openRead(inFileName);
	K = readInt(f);
	lb = readInt(f);
	ub = readInt(f);
	r[1..K] = readInt(f);
	d[1..K] = readInt(f);
	beta[1..K] = readInt(f);	
	totalDemand = sum[i in 1..K] (r[i]);
	maxDemand = max[i in 1..K] (r[i]);
	maxBatches = lb > 0 ? ceil(totalDemand / (lb + 0.0)) : totalDemand;	
	println("nbVar:" + maxBatches * K * maxDemand);
}


function model(){
	for[k in 1..K]{
		for[b in 1..maxBatches]
			for[i in 1..maxDemand]
				x[k][b][i] <- bool(); //i-th element of customer k is in batch b
			
		//meet the request
		constraint sum[b in 1..maxBatches][i in 1..maxDemand] (x[k][b][i]) == r[k];
	}
	
	//batch size
	for [b in 1..maxBatches]{
		size[b] <- sum[k in 1..K][i in 1..maxDemand] (x[k][b][i]);
		constraint size[b] > 0 ? lb <= size[b] : true;
		constraint size[b] <= ub;		
	}
	
	//starting & completion time of each batch
	s[1] <- 0;
	c[1] <- size[1];
	for [b in 2..maxBatches]{
		s[b] <- c[b-1];
		c[b] <- s[b] + size[b];
	}
	
	for[k in 1..K][b in 1..maxBatches]{
		q[k][b] <- sum[i in 1..maxDemand] (x[k][b][i]);
		T[k][b] <- q[k][b] > 0 ? max(c[b] - d[k], 0) : 0;
	}
	
	minimize sum[k in 1..K][b in 1..maxBatches](T[k][b]*q[k][b]*beta[k]);
}

function param(){
	setObjectiveBound(0,0);
	if(lsTimeLimit==nil) lsTimeLimit=5;
}

function output(){
	for[k in 1..K]{
		print("customer "+ k + ":\t");
		for[b in 1..maxBatches]{
			print(getValue(q[k][b])+ "\t");
		}
		println();
	}
	println();
	for[b in 1..maxBatches]{
		if(getValue(size[b]) > 0)
			println("batch "+ b + ":\t[" + getValue(s[b]) + "\t"+ getValue(c[b]) + "]\t");
	}
}